cis_config: /root/cis_interface/cis_interface/cis_interface/communication/DefaultComm.h Source File

cis_config

DefaultComm.h
1 #include <CommBase.h>
2
4 #ifndef CISDEFAULTCOMM_H_
5 #define CISDEFAULTCOMM_H_
6
7 // IPC Comm
8 #ifdef IPCDEF
9 #include <IPCComm.h>
10 static comm_type _default_comm = IPC_COMM;
11 #define new_default_address new_ipc_address
12 #define init_default_comm init_ipc_comm
13 #define free_default_comm free_ipc_comm
14 #define default_comm_nmsg ipc_comm_nmsg
15 #define default_comm_send ipc_comm_send
16 #define default_comm_recv ipc_comm_recv
17 // ZMQ Comm
18 #else
19 #include <ZMQComm.h>
20 static comm_type _default_comm = ZMQ_COMM;
21 #define new_default_address new_zmq_address
22 #define init_default_comm init_zmq_comm
23 #define free_default_comm free_zmq_comm
24 #define default_comm_nmsg zmq_comm_nmsg
25 #define default_comm_send zmq_comm_send
26 #define default_comm_recv zmq_comm_recv
27 #endif
28
29 #endif /*CISDEFAULTCOMM_H_*/